import { ElementRef, EventEmitter, NgZone, OnDestroy, Renderer2, AfterViewInit } from '@angular/core';
import { SpotlightService } from './spotlight.service';
/** container + all 4 sides + overlay */
export declare type SpotlightElementName = 'container' | 'backdrop-top' | 'backdrop-bottom' | 'backdrop-left' | 'backdrop-right' | 'overlay' | 'border-top' | 'border-bottom' | 'border-left' | 'border-right';
/**
 * Spotlight directive
 *
 * This lets you to spotlight certain elements
 * by placing 4 dark transparent divs around it
 */
export declare class SpotlightDirective implements AfterViewInit, OnDestroy {
    private _spotlightService;
    readonly elementRef: ElementRef<HTMLElement>;
    private _renderer;
    private _zone;
    /** spotlight id */
    id: string;
    /** draw border around spotlight element */
    border: boolean;
    /** space around spotlight element */
    indent: number;
    /** draw transparent overlay on spotlight element */
    overlay: boolean;
    /** highlight element after view init */
    auto: boolean;
    /** border width */
    borderWidth: number;
    /** backdrop and overlay click event */
    spotlightClick: EventEmitter<{
        piece: SpotlightElementName;
        mouse: MouseEvent;
    }>;
    /** whether the directive is shown */
    private _isShown;
    /** whether the spotlight is shown */
    get isShown(): boolean;
    /** main spotlight container */
    get container(): HTMLElement;
    /** destroy subject (pattern) */
    private readonly _destroy$;
    /** set of all created corresponding elements (backdrops, borders and overlay) */
    private readonly _elementMap;
    /**
     * Set of listeners that should be "unlistened" on destroying
     * @see https://angular.io/api/core/Renderer2#listen
     */
    private _listenerSet;
    /** global window */
    private _window;
    constructor(_spotlightService: SpotlightService, _window: any, elementRef: ElementRef<HTMLElement>, _renderer: Renderer2, _zone: NgZone);
    ngAfterViewInit(): void;
    /**
     * Shows the overlay
     * - Scrolls the page to the very top
     * - Places 4 overlays around the element
     */
    show(): void;
    /**
     * Places container to document body
     */
    private _drawContainer;
    /**
     * Places 4 backdrops around the elementRef
     */
    private _drawBackdrop;
    /**
     * Places 4 div around the spotlight to emulate stroke
     */
    private _drawBorder;
    /**
     * Watches for window scroll&resize and, when it occurs, modifies the layers styles
     */
    private _watchWindowUpdate;
    /**
     * Sets backdrop piece styles
     * @param element - the element to mutate
     * @param props - the limited set of CSS properties
     */
    private _setStyles;
    /**
     * Modifies the given layer's styles **by mutating it**
     * @param el - backdrop's layer HTML element
     * @param piece - piece of spotlight element
     */
    private _modifyPieceStyle;
    /**
     * Draws an invisible element over the spotlighted element from the DOM
     */
    private _drawOverlay;
    /**
     * Removes the spotlight for this element
     */
    hide(): void;
    /**
     * Removes the backdrop and the overlay elements from the DOM
     */
    private _removeElements;
    ngOnDestroy(): void;
}
